@@ -6,14 +6,14 @@
 #define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "freebsd5.4"
-#define HOST_OS_NAME "freebsd5"
-#define HOST_OS_VERSION "5.4"
+#define HOST_OS "freebsd6.0"
+#define HOST_OS_NAME "freebsd6"
+#define HOST_OS_VERSION "6.0"
 #define HOST_ARCH "i386"
 #define DISTRO_NAME "none"
-#define HOST_NAME "a-freebsd54.fsl.cs.sunysb.edu"
+#define HOST_NAME "a-freebsd60.fsl.cs.sunysb.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Tue Oct 18 13:50:24 EDT 2005"
+#define CONFIG_DATE "Wed May 10 10:52:38 EDT 2006"
 #define PACKAGE_NAME "am-utils"
 #define PACKAGE_VERSION "6.2a2"
 #define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
@@ -34,7 +34,7 @@
 #ifdef __cplusplus
 #include <stdlib.h>
 #endif
-#define HOST_HEADER_VERSION "5.4"
+#define HOST_HEADER_VERSION "6.0"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_UNISTD_H 1
@@ -240,6 +240,7 @@
 #define HAVE_TIME_H 1
 #define HAVE_UNISTD_H 1
 #define HAVE_HESIOD_H 1
+#define NEW_DBM_H "ndbm.h"
 #define TIME_WITH_SYS_TIME 1
 #define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_freebsd3.h"
 #define HAVE_STRUCT_NFS_ARGS 1
@@ -321,6 +322,7 @@
 #define HAVE_MAP_SUN 1
 #define HAVE_MAP_EXEC 1
 #define HAVE_MAP_HESIOD 1
+#define HAVE_MAP_NDBM 1
 #define HAVE_MAP_NIS 1
 #define HAVE_MAP_PASSWD 1
 #define HAVE_MAP_UNION 1
@@ -356,7 +358,7 @@
 #define MNT2_GEN_OPT_ASYNC 0x40
 #define MNT2_GEN_OPT_FORCE 0x80000
 #define MNT2_GEN_OPT_IGNORE 0x800000
-#define MNT2_GEN_OPT_NODEV 0x10
+#define MNT2_GEN_OPT_NODEV 0x0
 #define MNT2_GEN_OPT_NOEXEC 0x4
 #define MNT2_GEN_OPT_NOSUID 0x8
 #define MNT2_GEN_OPT_QUOTA 0x2000
@@ -384,6 +386,9 @@
 #define MNT2_CDFS_OPT_EXTATT 0x4
 #define MNT2_CDFS_OPT_GENS 0x2
 #define MNT2_CDFS_OPT_NORRIP 0x1
+#define MNT2_PCFS_OPT_LONGNAME 0x2
+#define MNT2_PCFS_OPT_NOWIN95 0x4
+#define MNT2_PCFS_OPT_SHORTNAME 0x1
 #define HIDE_MOUNT_TYPE "nfs"
 #define USE_CONNECTED_NFS_SOCKETS 1
 #define HAVE_LIBWRAP 1
